@@ -1,4 +1,4 @@
-writeOGR <- function(obj, dsn, layer, driver, dataset_options=NULL, layer_options=NULL, verbose=FALSE, check_exists=NULL, overwrite_layer=FALSE, delete_dsn=FALSE, morphToESRI=NULL, encoding=NULL) {
+writeOGR <- function(obj, dsn, layer, driver, dataset_options=NULL, layer_options=NULL, verbose=FALSE, check_exists=NULL, overwrite_layer=FALSE, delete_dsn=FALSE, morphToESRI=NULL, encoding=NULL, shp_edge_case_fix=FALSE, dumpSRS=FALSE) {
     if (missing(dsn)) stop("missing dsn")
     stopifnot(is.character(dsn))
     stopifnot(length(dsn) == 1L)
@@ -22,6 +22,9 @@ writeOGR <- function(obj, dsn, layer, driver, dataset_options=NULL, layer_option
 # fix for over-eager internal checking in the KML driver 090114
     }
     is_shpfile <- driver == "ESRI Shapefile"
+    stopifnot(is.logical(is_shpfile))
+    stopifnot(length(is_shpfile) == 1)
+    stopifnot(!is.na(is_shpfile))
     stopifnot(inherits(obj, "Spatial"))
     if (gridded(obj)) {
         obj <- as(obj, "SpatialPointsDataFrame")
@@ -105,6 +108,7 @@ writeOGR <- function(obj, dsn, layer, driver, dataset_options=NULL, layer_option
         morphToESRI <- ifelse(is_shpfile, TRUE, FALSE)
     stopifnot(is.logical(morphToESRI))
     stopifnot(length(morphToESRI) == 1)
+    stopifnot(!is.na(morphToESRI))
 
     nf <- length(dfcls)
     ldata <- vector(mode="list", length=nf)
@@ -170,12 +174,20 @@ writeOGR <- function(obj, dsn, layer, driver, dataset_options=NULL, layer_option
     attr(nf, "verbose") <- as.logical(verbose)
     driver <- as.character(driver)
     attr(driver, "is_shpfile") <- is_shpfile
+    stopifnot(is.logical(shp_edge_case_fix))
+    stopifnot(length(shp_edge_case_fix) == 1)
+    stopifnot(!is.na(shp_edge_case_fix))
+    attr(driver, "shp_edge_case_fix") <- shp_edge_case_fix && is_shpfile
+    stopifnot(is.logical(dumpSRS))
+    stopifnot(length(dumpSRS) == 1)
+    stopifnot(!is.na(dumpSRS))
+    attr(morphToESRI, "dumpSRS") <- dumpSRS
     
     pre <- list(obj, as.character(dsn), as.character(layer), 
         driver, as.integer(nobj), nf,
         as.character(fld_names), as.integer(ogr_ftype), ldata, 
         as.character(dataset_options), as.character(layer_options),
-        as.logical(morphToESRI), as.integer(FIDs))
+        morphToESRI, as.integer(FIDs))
     res <- .Call("OGR_write", pre, PACKAGE="rgdal")
     NAs <- !(fld_names == attr(res, "ofld_nms"))
     if (any(NAs) && is_shpfile) {
@@ -190,7 +202,8 @@ writeOGR <- function(obj, dsn, layer, driver, dataset_options=NULL, layer_option
             output_diver=driver, output_n=nobj, output_nfields=nf,
             output_fields=fld_names, output_fclasses=ogr_ftype, 
             dataset_options=dataset_options, layer_options=layer_options,
-            morphToESRI=morphToESRI, FIDs=FIDs)
+            morphToESRI=morphToESRI, FIDs=FIDs,
+            shp_edge_case_fix=shp_edge_case_fix)
         return(res)
 # add FIDs 130502
     } 
@@ -203,7 +216,7 @@ ogrDeleteLayer <- function(dsn, layer, driver) {
     if (nchar(layer) == 0) stop("empty name")
     if (missing(driver)) stop("missing layer")
     if (nchar(driver) == 0) stop("empty name")
-    res <- .Call("ogrDeleteLayer", as.character(dsn), as.character(layer),
+    res <- .Call("RGDAL_ogrDeleteLayer", as.character(dsn), as.character(layer),
         as.character(driver), PACKAGE = "rgdal")
     invisible(res)
 }
@@ -213,7 +226,7 @@ ogrDeleteDataSource <- function(dsn, driver) {
     if (nchar(dsn) == 0) stop("empty name")
     if (missing(driver)) stop("missing layer")
     if (nchar(driver) == 0) stop("empty name")
-    res <- .Call("ogrDeleteDataSource", as.character(dsn), as.character(driver),
+    res <- .Call("RGDAL_ogrDeleteDataSource", as.character(dsn), as.character(driver),
         PACKAGE = "rgdal")
     invisible(res)
 
