@@ -137,7 +137,35 @@ SEXP RGDAL_projInfo(SEXP type) {
         SET_STRING_ELT(ansnames, 1, COPY_TO_USER_STRING("to_meter"));
         SET_STRING_ELT(ansnames, 2, COPY_TO_USER_STRING("name"));
         setAttrib(ans, R_NamesSymbol, ansnames);
-
+#if ((PROJ_VERSION_MAJOR == 7 && PROJ_VERSION_MINOR >= 1) || PROJ_VERSION_MAJOR > 7)
+        PROJ_UNIT_INFO** units;
+        units = proj_get_units_from_database(nullptr, nullptr, "linear", false, nullptr);
+        n = 0;
+//Rprintf("n: %d\n", n);
+        for (int i = 0; units && units[i]; i++) {
+            if (units[i]->proj_short_name) n++;
+//Rprintf("%s\n", units[i]->proj_short_name);
+        }
+//Rprintf("n: %d\n", n);
+        SET_VECTOR_ELT(ans, 0, NEW_CHARACTER(n));
+        SET_VECTOR_ELT(ans, 1, NEW_NUMERIC(n));
+        SET_VECTOR_ELT(ans, 2, NEW_CHARACTER(n));
+        int n1=0;
+        for (int i = 0; units && units[i]; i++) {
+            if (units[i]->proj_short_name) {
+                SET_STRING_ELT(VECTOR_ELT(ans, 0), n1, 
+		    COPY_TO_USER_STRING(units[i]->proj_short_name));
+                NUMERIC_POINTER(VECTOR_ELT(ans, 1))[n1] = units[i]->conv_factor;
+                SET_STRING_ELT(VECTOR_ELT(ans, 2), n1, 
+		    COPY_TO_USER_STRING(units[i]->name));
+                n1++;
+//Rprintf("%s %f %s\n", units[i]->proj_short_name, units[i]->conv_factor, units[i]->name);
+            }
+            if (n1 >= n) break; //EPJ correction
+        }
+        proj_unit_list_destroy(units);
+// >= 710 proj_get_units_from_database()
+#else
         const struct PJ_UNITS *lu;
         for (lu = proj_list_units(); lu->id ; ++lu) n++;
         SET_VECTOR_ELT(ans, 0, NEW_CHARACTER(n));
@@ -153,6 +181,7 @@ SEXP RGDAL_projInfo(SEXP type) {
 		COPY_TO_USER_STRING(lu->name));
             n++;
         }
+#endif
     } else error("no such type");
     
     UNPROTECT(pc);
@@ -169,11 +198,35 @@ SEXP get_proj_search_path(void) {
 
 }
 
+SEXP set_proj_search_path(SEXP path) {
+#if PROJ_VERSION_MAJOR > 6
+    Rprintf("Not available for PROJ version 6");
+    return(R_NilValue);
+// sf usage for only one path component
+#else
+    //PJ_CONTEXT *ctx = proj_context_create();
+    SEXP res;
+    const char *paths = CHAR(STRING_ELT(path, 0));
+    proj_context_set_search_paths(PJ_DEFAULT_CTX, 1, &paths);
+    if (int this_errno = proj_context_errno(PJ_DEFAULT_CTX) != 0) {
+        const char *errstr = proj_errno_string(this_errno);
+        //proj_context_destroy(ctx);
+	error("setting search path failed: %s", errstr);
+    }
+    PROTECT(res = NEW_CHARACTER(1));
+    SET_STRING_ELT(res, 0, COPY_TO_USER_STRING(proj_info().searchpath));
+    UNPROTECT(1);
+    //proj_context_destroy(ctx);
+    return(res);
+#endif
+}
+
+
 // unname(sapply(o[[2]], function(x) gsub(" ", " +", paste0("+", x))))
 
 SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP strict_containment, SEXP vis_order) {
 
-    PJ_CONTEXT *ctx = proj_context_create();
+    //PJ_CONTEXT *ctx = proj_context_create();
     PJ_OPERATION_FACTORY_CONTEXT* operation_factory_context = NULL;
     PJ_OBJ_LIST *pj_operations = NULL;
     PJ *source_crs, *target_crs;
@@ -186,32 +239,32 @@ SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP s
     const char *out_short_name, *out_full_name, *out_package_name, *out_url;
     PJ_PROJ_INFO pjinfo;
 
-    source_crs = proj_create(ctx, CHAR(STRING_ELT(source, 0)));
+    source_crs = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(source, 0)));
 
     if (source_crs == NULL) {
-        proj_context_destroy(ctx);
+        //proj_context_destroy(ctx);
         error("source crs not created");
     }
     
-    target_crs = proj_create(ctx, CHAR(STRING_ELT(target, 0)));
+    target_crs = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(target, 0)));
 
     if (target_crs == NULL) {
         proj_destroy(source_crs);
-        proj_context_destroy(ctx);
+        //proj_context_destroy(ctx);
         error("target crs not created");
     }
 
-    operation_factory_context = proj_create_operation_factory_context(ctx,
+    operation_factory_context = proj_create_operation_factory_context(PJ_DEFAULT_CTX,
         NULL);
     if (operation_factory_context == NULL) {
         proj_destroy(source_crs); proj_destroy(target_crs);
-        proj_context_destroy(ctx);
+        //proj_context_destroy(ctx);
         error("operation factory context not created");
     }
 
     if (!ISNA(NUMERIC_POINTER(area_of_interest)[0])) {
         proj_operation_factory_context_set_area_of_interest(
-            ctx, operation_factory_context,
+            PJ_DEFAULT_CTX, operation_factory_context,
             NUMERIC_POINTER(area_of_interest)[0],
             NUMERIC_POINTER(area_of_interest)[1],
             NUMERIC_POINTER(area_of_interest)[2],
@@ -220,23 +273,23 @@ SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP s
 
     if (LOGICAL_POINTER(strict_containment)[0])
         proj_operation_factory_context_set_spatial_criterion(
-            ctx, operation_factory_context,
+            PJ_DEFAULT_CTX, operation_factory_context,
             PROJ_SPATIAL_CRITERION_STRICT_CONTAINMENT);
     else proj_operation_factory_context_set_spatial_criterion(
-            ctx, operation_factory_context,
+            PJ_DEFAULT_CTX, operation_factory_context,
             PROJ_SPATIAL_CRITERION_PARTIAL_INTERSECTION);
 
     proj_operation_factory_context_set_grid_availability_use(
-            ctx, operation_factory_context,
+            PJ_DEFAULT_CTX, operation_factory_context,
             PROJ_GRID_AVAILABILITY_USED_FOR_SORTING);
 
-    pj_operations = proj_create_operations(ctx,
+    pj_operations = proj_create_operations(PJ_DEFAULT_CTX,
                 source_crs, target_crs, operation_factory_context);
     
     if (pj_operations == NULL) {
         proj_operation_factory_context_destroy(operation_factory_context);
         proj_destroy(source_crs); proj_destroy(target_crs);
-        proj_context_destroy(ctx);
+        //proj_context_destroy(ctx);
         error("operations list not created");
     }
 
@@ -246,7 +299,7 @@ SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP s
         proj_list_destroy(pj_operations);
         proj_operation_factory_context_destroy(operation_factory_context);
         proj_destroy(source_crs); proj_destroy(target_crs);
-        proj_context_destroy(ctx);
+        //proj_context_destroy(ctx);
         return(R_NilValue);
     }
 
@@ -269,16 +322,16 @@ SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP s
 
 
     for (i=0; i<num_operations; i++) {
-        pj_transform = proj_list_get(ctx, pj_operations, i);
+        pj_transform = proj_list_get(PJ_DEFAULT_CTX, pj_operations, i);
         if (LOGICAL_POINTER(vis_order)[0])
-            pj_transform = proj_normalize_for_visualization(ctx, pj_transform);
-        is_instantiable = proj_coordoperation_is_instantiable(ctx,
+            pj_transform = proj_normalize_for_visualization(PJ_DEFAULT_CTX, pj_transform);
+        is_instantiable = proj_coordoperation_is_instantiable(PJ_DEFAULT_CTX,
             pj_transform);
-        is_ballpark = proj_coordoperation_has_ballpark_transformation(ctx,
+        is_ballpark = proj_coordoperation_has_ballpark_transformation(PJ_DEFAULT_CTX,
             pj_transform);
-        accuracy = proj_coordoperation_get_accuracy(ctx,
+        accuracy = proj_coordoperation_get_accuracy(PJ_DEFAULT_CTX,
             pj_transform);
-        grid_count = proj_coordoperation_get_grid_used_count(ctx,
+        grid_count = proj_coordoperation_get_grid_used_count(PJ_DEFAULT_CTX,
             pj_transform);
         pjinfo = proj_pj_info(pj_transform);
         SET_STRING_ELT(VECTOR_ELT(ans, 0), i,
@@ -294,7 +347,7 @@ SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP s
         if (grid_count > 0L) {
             SET_VECTOR_ELT(VECTOR_ELT(ans, 6), i, NEW_LIST(grid_count));
             for (j=0; j<grid_count; j++) {
-                grid_OK = proj_coordoperation_get_grid_used(ctx, pj_transform,
+                grid_OK = proj_coordoperation_get_grid_used(PJ_DEFAULT_CTX, pj_transform,
                     j, &out_short_name, &out_full_name, &out_package_name,
                     &out_url, &out_direct_download, &out_open_license,
                     &out_available);
@@ -346,7 +399,7 @@ SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP s
     proj_list_destroy(pj_operations);
     proj_operation_factory_context_destroy(operation_factory_context);
     proj_destroy(source_crs); proj_destroy(target_crs);
-    proj_context_destroy(ctx);
+    //proj_context_destroy(ctx);
 
     UNPROTECT(pc);
     return(ans);
@@ -355,23 +408,23 @@ SEXP list_coordinate_ops(SEXP source, SEXP target, SEXP area_of_interest, SEXP s
 
 SEXP CRS_compare(SEXP fromargs, SEXP toargs, SEXP type1, SEXP type2) {
 
-    PJ_CONTEXT *ctx = proj_context_create();
+    //PJ_CONTEXT *ctx = proj_context_create();
     PJ *source_crs, *target_crs;
     SEXP res;
     int ires_strict, ires_equiv, ires_equiv_ao;
 //Rprintf("source crs input: %s\n", CHAR(STRING_ELT(fromargs, 0)));
-    if ((source_crs = proj_create(ctx, CHAR(STRING_ELT(fromargs, 0)))) == NULL) {
-        const char *errstr = proj_errno_string(proj_context_errno(ctx));
-        proj_context_destroy(ctx);
+    if ((source_crs = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(fromargs, 0)))) == NULL) {
+        const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+        //proj_context_destroy(ctx);
 	error("source crs creation failed: %s", errstr);
     }
 	
 //Rprintf("source crs: %s\n", proj_pj_info(source_crs).description); not filled for WKT
 //Rprintf("target crs input:  %s\n", CHAR(STRING_ELT(toargs, 0)));
-    if ((target_crs = proj_create(ctx, CHAR(STRING_ELT(toargs, 0)))) == NULL) {
+    if ((target_crs = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(toargs, 0)))) == NULL) {
         proj_destroy(source_crs);
-        const char *errstr = proj_errno_string(proj_context_errno(ctx));
-        proj_context_destroy(ctx);
+        const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+        //proj_context_destroy(ctx);
         error("target crs creation failed: %s", errstr);
     }
 //Rprintf("target crs: %s\n", proj_pj_info(target_crs).description); not filled for WKT
@@ -383,11 +436,11 @@ SEXP CRS_compare(SEXP fromargs, SEXP toargs, SEXP type1, SEXP type2) {
     ires_equiv_ao = proj_is_equivalent_to(source_crs, target_crs,
         PJ_COMP_EQUIVALENT_EXCEPT_AXIS_ORDER_GEOGCRS);
 #else
-    ires_strict = proj_is_equivalent_to_with_ctx(ctx, source_crs, target_crs,
+    ires_strict = proj_is_equivalent_to_with_ctx(PJ_DEFAULT_CTX, source_crs, target_crs,
         PJ_COMP_STRICT);
-    ires_equiv = proj_is_equivalent_to_with_ctx(ctx, source_crs, target_crs,
+    ires_equiv = proj_is_equivalent_to_with_ctx(PJ_DEFAULT_CTX, source_crs, target_crs,
         PJ_COMP_EQUIVALENT);
-    ires_equiv_ao = proj_is_equivalent_to_with_ctx(ctx, source_crs, target_crs,
+    ires_equiv_ao = proj_is_equivalent_to_with_ctx(PJ_DEFAULT_CTX, source_crs, target_crs,
         PJ_COMP_EQUIVALENT_EXCEPT_AXIS_ORDER_GEOGCRS);
 #endif
 //Rprintf("ires: %d, iresao\n", ires);
@@ -397,14 +450,14 @@ SEXP CRS_compare(SEXP fromargs, SEXP toargs, SEXP type1, SEXP type2) {
     INTEGER_POINTER(res)[2] = ires_equiv_ao;
     proj_destroy(target_crs);
     proj_destroy(source_crs);
-    proj_context_destroy(ctx);
+    //proj_context_destroy(ctx);
     UNPROTECT(1);
     return(res);
 }
 
 SEXP transform_ng(SEXP fromargs, SEXP toargs, SEXP coordOp, SEXP npts, SEXP x, SEXP y, SEXP z) {
 
-    PJ_CONTEXT *ctx = proj_context_create();
+    //PJ_CONTEXT *ctx = proj_context_create();
     PJ *source_crs = NULL, *target_crs = NULL;
     PJ* pj_transform = NULL;
 
@@ -429,41 +482,41 @@ SEXP transform_ng(SEXP fromargs, SEXP toargs, SEXP coordOp, SEXP npts, SEXP x, S
 
     if (have_CO) {
 //Rprintf("coordinate operation input: %s\n", CHAR(STRING_ELT(coordOp, 0)));
-        if ((pj_transform = proj_create(ctx, CHAR(STRING_ELT(coordOp, 0)))) == 0) {
-            const char *errstr = proj_errno_string(proj_context_errno(ctx));
-            proj_context_destroy(ctx);
+        if ((pj_transform = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(coordOp, 0)))) == 0) {
+            const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+            //proj_context_destroy(ctx);
 	    error("coordinate operation creation failed: %s", errstr);
         }
 //        pj_transform = proj_normalize_for_visualization(ctx, pj_transform);
 
     } else {
 //Rprintf("source crs input: %s\n", CHAR(STRING_ELT(fromargs, 0)));
-    	if ((source_crs = proj_create(ctx, CHAR(STRING_ELT(fromargs, 0)))) == NULL) {
-            const char *errstr = proj_errno_string(proj_context_errno(ctx));
-            proj_context_destroy(ctx);
+    	if ((source_crs = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(fromargs, 0)))) == NULL) {
+            const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+            //proj_context_destroy(ctx);
 	    error("source crs creation failed: %s", errstr);
         }
 	
 //Rprintf("source crs: %s\n", proj_pj_info(source_crs).description); 
 //Rprintf("target crs input:  %s\n", CHAR(STRING_ELT(toargs, 0)));
-	if ((target_crs = proj_create(ctx, CHAR(STRING_ELT(toargs, 0)))) == NULL) {
+	if ((target_crs = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(toargs, 0)))) == NULL) {
             proj_destroy(source_crs);
-            const char *errstr = proj_errno_string(proj_context_errno(ctx));
-            proj_context_destroy(ctx);
+            const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+            //proj_context_destroy(ctx);
 	    error("target crs creation failed: %s", errstr);
         }
 //Rprintf("target crs: %s\n", proj_pj_info(target_crs).description); 
-        if ((pj_transform = proj_create_crs_to_crs_from_pj(ctx, source_crs,
+        if ((pj_transform = proj_create_crs_to_crs_from_pj(PJ_DEFAULT_CTX, source_crs,
             target_crs, 0, NULL)) == 0) {
             proj_destroy(target_crs);
             proj_destroy(source_crs);
-            const char *errstr = proj_errno_string(proj_context_errno(ctx));
-            proj_context_destroy(ctx);
+            const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+            //proj_context_destroy(ctx);
 	    error("coordinate operation creation from WKT failed: %s", errstr);
         }
 //Rprintf("%s\n", proj_pj_info(pj_transform).definition);
         if (vis_order == 1) 
-            pj_transform = proj_normalize_for_visualization(ctx, pj_transform);
+            pj_transform = proj_normalize_for_visualization(PJ_DEFAULT_CTX, pj_transform);
 
     }
 //Rprintf("%s\n", proj_pj_info(pj_transform).definition);
@@ -498,8 +551,8 @@ SEXP transform_ng(SEXP fromargs, SEXP toargs, SEXP coordOp, SEXP npts, SEXP x, S
                 proj_destroy(target_crs);
                 proj_destroy(source_crs);
             }
-            const char *errstr = proj_errno_string(proj_context_errno(ctx));
-            proj_context_destroy(ctx);
+            const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+            //proj_context_destroy(ctx);
             error("error in proj_transform_generic: %n of %n coordinates succeeded\n  %s", n1, n, errstr);
 	    }
     } else {
@@ -511,8 +564,8 @@ SEXP transform_ng(SEXP fromargs, SEXP toargs, SEXP coordOp, SEXP npts, SEXP x, S
               proj_destroy(target_crs);
               proj_destroy(source_crs);
           }
-          const char *errstr = proj_errno_string(proj_context_errno(ctx));
-          proj_context_destroy(ctx);
+          const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+          //proj_context_destroy(ctx);
           error("error in proj_transform_generic: %n of %n coordinates succeeded\n  %s", n1, n, errstr);
         }
     }
@@ -570,7 +623,7 @@ SEXP transform_ng(SEXP fromargs, SEXP toargs, SEXP coordOp, SEXP npts, SEXP x, S
          proj_destroy(target_crs);
          proj_destroy(source_crs);
     }
-    proj_context_destroy(ctx);
+    //proj_context_destroy(ctx);
 
     if (have_z) {
         for (i=0; i < n; i++) {
@@ -603,13 +656,13 @@ SEXP transform_ng(SEXP fromargs, SEXP toargs, SEXP coordOp, SEXP npts, SEXP x, S
 SEXP project_ng_coordOp(SEXP proj, SEXP inv//, SEXP ob_tran
 ) {
 
-    PJ_CONTEXT *ctx = proj_context_create();
+    //PJ_CONTEXT *ctx = proj_context_create();
     PJ *source_crs, *target_crs;
     PJ* pj_transform = NULL;
     int //use_ob_tran = LOGICAL_POINTER(ob_tran)[0], 
         use_inv;
 
-    proj_log_func(ctx, NULL, silent_logger);
+    proj_log_func(PJ_DEFAULT_CTX, NULL, silent_logger);
 
 /*    if (ob_tran == R_NilValue) use_ob_tran = 0;
     else if (LOGICAL_POINTER(ob_tran)[0] == 1) use_ob_tran = 1;
@@ -622,34 +675,34 @@ SEXP project_ng_coordOp(SEXP proj, SEXP inv//, SEXP ob_tran
     else use_inv = 0;
 
 //Rprintf("target crs input: %s\n", CHAR(STRING_ELT(proj, 0)));
-    if ((target_crs = proj_create(ctx, CHAR(STRING_ELT(proj, 0)))) == 0) {
-        const char *errstr = proj_errno_string(proj_context_errno(ctx));
-        proj_context_destroy(ctx);
+    if ((target_crs = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(proj, 0)))) == 0) {
+        const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+        //proj_context_destroy(ctx);
 	error("target crs creation failed: %s", errstr);
     }
 	
 //Rprintf("target crs: %s\n", proj_pj_info(target_crs).definition); 
-    if ((source_crs = proj_crs_get_geodetic_crs(ctx, target_crs)) == 0) {
-        const char *errstr = proj_errno_string(proj_context_errno(ctx));
+    if ((source_crs = proj_crs_get_geodetic_crs(PJ_DEFAULT_CTX, target_crs)) == 0) {
+        const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
         proj_destroy(target_crs);
-        proj_context_destroy(ctx);
+        //proj_context_destroy(ctx);
         error("source crs creation failed: %s", errstr);
     }
 //Rprintf("source crs: %s\n", proj_pj_info(source_crs).definition); 
-    if (use_inv) pj_transform = proj_create_crs_to_crs_from_pj(ctx, target_crs,
+    if (use_inv) pj_transform = proj_create_crs_to_crs_from_pj(PJ_DEFAULT_CTX, target_crs,
         source_crs, 0, NULL);
-    else pj_transform = proj_create_crs_to_crs_from_pj(ctx, source_crs,
+    else pj_transform = proj_create_crs_to_crs_from_pj(PJ_DEFAULT_CTX, source_crs,
         target_crs, 0, NULL);
 
     if (pj_transform == 0) {
         proj_destroy(target_crs);
         proj_destroy(source_crs);
-        const char *errstr = proj_errno_string(proj_context_errno(ctx));
-        proj_context_destroy(ctx);
+        const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+        //proj_context_destroy(ctx);
         error("coordinate operation creation failed: %s", errstr);
     }
 //Rprintf("%s\n", proj_pj_info(pj_transform).definition);
-    pj_transform = proj_normalize_for_visualization(ctx, pj_transform);
+    pj_transform = proj_normalize_for_visualization(PJ_DEFAULT_CTX, pj_transform);
 //Rprintf("%s\n", proj_pj_info(pj_transform).definition);
 
     SEXP res;
@@ -660,7 +713,7 @@ SEXP project_ng_coordOp(SEXP proj, SEXP inv//, SEXP ob_tran
     proj_destroy(pj_transform);
     proj_destroy(target_crs);
     proj_destroy(source_crs);
-    proj_context_destroy(ctx);
+    //proj_context_destroy(ctx);
 
     return(res);
 }
@@ -669,16 +722,16 @@ SEXP project_ng(SEXP n, SEXP xlon, SEXP ylat, SEXP zz, SEXP inv, SEXP ob_tran, S
     int i, nwarn=0, is_ob_tran=LOGICAL_POINTER(ob_tran)[0], 
         nn=INTEGER_POINTER(n)[0], use_inv=LOGICAL_POINTER(inv)[0];
     SEXP res;
-    PJ_CONTEXT *ctx = proj_context_create();
+    //PJ_CONTEXT *ctx = proj_context_create();
     PJ* pj_transform = NULL;
     PJ_COORD a, b;
     double ixlon, iylat, iz=0.0;
 
-    proj_log_func(ctx, NULL, silent_logger);
+    proj_log_func(PJ_DEFAULT_CTX, NULL, silent_logger);
 
-    if ((pj_transform = proj_create(ctx, CHAR(STRING_ELT(coordOp, 0)))) == 0) {
-        const char *errstr = proj_errno_string(proj_context_errno(ctx));
-        proj_context_destroy(ctx);
+    if ((pj_transform = proj_create(PJ_DEFAULT_CTX, CHAR(STRING_ELT(coordOp, 0)))) == 0) {
+        const char *errstr = proj_errno_string(proj_context_errno(PJ_DEFAULT_CTX));
+        //proj_context_destroy(ctx);
         error("coordinate operation creation failed: %s", errstr);
     }
 //Rprintf("%s\n", proj_pj_info(pj_transform).definition);
@@ -717,7 +770,7 @@ SEXP project_ng(SEXP n, SEXP xlon, SEXP ylat, SEXP zz, SEXP inv, SEXP ob_tran, S
     if (nwarn > 0) warning("%d projected point(s) not finite", nwarn);
 
     proj_destroy(pj_transform);
-    proj_context_destroy(ctx);
+    //proj_context_destroy(ctx);
 
     UNPROTECT(1);
     return(res);
@@ -800,12 +853,12 @@ PROJcopyEPSG(SEXP tf) {
     INTEGER_POINTER(ans)[0] = 0;
     int i, crs_cnt;
     PROJ_CRS_INFO **proj_crs_info;
-    PJ_CONTEXT *ctx = proj_context_create();
+    //PJ_CONTEXT *ctx = proj_context_create();
     FILE *fptf;
 
 	
     crs_cnt = 0;
-    proj_crs_info = proj_get_crs_info_list_from_database(ctx, "EPSG", NULL,
+    proj_crs_info = proj_get_crs_info_list_from_database(PJ_DEFAULT_CTX, "EPSG", NULL,
         &crs_cnt);
     if (crs_cnt < 1) {
         UNPROTECT(1);
@@ -820,13 +873,13 @@ PROJcopyEPSG(SEXP tf) {
 
     PJ *pj = NULL;
 // blocks error messages in this context
-    proj_log_func(ctx, NULL, proj_logger);
+    proj_log_func(PJ_DEFAULT_CTX, NULL, proj_logger);
     for (i = 0; i < crs_cnt; i++) {
         const char *proj_definition;
 
-        pj = proj_create_from_database(ctx, proj_crs_info[i]->auth_name,
+        pj = proj_create_from_database(PJ_DEFAULT_CTX, proj_crs_info[i]->auth_name,
             proj_crs_info[i]->code, PJ_CATEGORY_CRS, 0, NULL);
-        proj_definition = proj_as_proj_string(ctx, pj, PJ_PROJ_5, NULL);
+        proj_definition = proj_as_proj_string(PJ_DEFAULT_CTX, pj, PJ_PROJ_5, NULL);
 
         fprintf(fptf, "%s,\"%s\",\"%s\",\"%s\"\n", proj_crs_info[i]->code,
   	    proj_crs_info[i]->name, proj_definition, 
@@ -836,7 +889,7 @@ PROJcopyEPSG(SEXP tf) {
     fclose(fptf);
     proj_destroy(pj);
     proj_crs_info_list_destroy(proj_crs_info);
-    proj_context_destroy(ctx);
+    //proj_context_destroy(ctx);
     INTEGER_POINTER(ans)[0] = crs_cnt;
     UNPROTECT(1);
 
